//
//  PicSelectView.swift
//  PictureChoose
//
//  Created by 刘春雷 on 2019/9/5.
//  Copyright © 2019 刘春雷. All rights reserved.
//

import UIKit

let SCREENW = UIScreen.main.bounds.size.width

class PicSelectView: UIView{

    var columnCount:Int = 3 // 每行显示的图片数量 默认是3个
    
    var contentViews = [UIView]()
    
    var originFrame:CGRect?
    
    var selectButton:UIButton?
    
    override init(frame: CGRect) {
       super.init(frame: frame)
        
    }
    convenience init(frame: CGRect,count:Int) {
        
        self.init(frame: frame)
        columnCount = count
        
        addWidgets()
        
    }
    required init?(coder aDecoder: NSCoder) {
        fatalError("init(coder:) has not been implemented")
    }
    
    private func addWidgets(){
        //距离父视图左右边距20  图片间距10
        let n = columnCount - 1
        //计算每个图片的宽度
        let width = (SCREENW - 40 - CGFloat( 10 * n ) ) / CGFloat(columnCount)
        
        let btn = UIButton(type: .custom)
        addSubview(btn)
        btn.layer.cornerRadius = 5
        btn.clipsToBounds = true
        btn.setImage(UIImage(named: "addpic"), for: UIControl.State.normal)
        //设置边框
//        btn.layer.borderColor  = UIColor.gray.cgColor
//        btn.layer.borderWidth = 0.5
        btn.addTarget(self, action: #selector(selectPicture), for: .touchUpInside)
        btn.frame = CGRect(x: 20, y: 10, width: width, height: width)
        contentViews.append(btn)
        selectButton = btn
        originFrame = btn.frame
        refreshView()
    
    }
    
    @objc func selectPicture(){
    
        let alertController = UIAlertController(title: "图片选择", message: "", preferredStyle: UIAlertController.Style.actionSheet)
        let cancelAction = UIAlertAction(title: "取消", style: UIAlertAction.Style.cancel) { (btn) in
            print("点击了取消")
        }
        let photoAlbumAction = UIAlertAction(title: "相册", style: UIAlertAction.Style.default) { (btn) in
            print("点击了相册")
            let picker = UIImagePickerController()
            picker.delegate = self
            picker.sourceType = .photoLibrary
            
            self.viewController()?.present(picker, animated: true, completion: nil)
        }
        let cameraAction = UIAlertAction(title: "相机", style: UIAlertAction.Style.default) { (btn) in
            print("点击了相机")
            let picker = UIImagePickerController()
            picker.delegate = self
            picker.sourceType = .camera
            
            self.viewController()?.present(picker, animated: true, completion: nil)
        }
        alertController.addAction(cancelAction)
        alertController.addAction(photoAlbumAction)
        alertController.addAction(cameraAction)
        self.viewController()?.present(alertController, animated: true, completion: nil)
        
    }
    
    fileprivate func addPicture(image:UIImage){
        let view = UIView()
        view.frame  = originFrame!
        addSubview(view)
        
        let imageView = UIImageView(frame: view.bounds)
        view.addSubview(imageView)
        imageView.image = image
        
        let cancelBtn = UIButton()
        cancelBtn.frame = CGRect(x: (originFrame?.size.width)! - 20, y: 0, width: 20, height: 20)
        cancelBtn.setImage(UIImage(named: "delete"), for: UIControl.State.normal)
        cancelBtn.addTarget(self, action: #selector(deletePic(sender:)), for: .touchUpInside)
        view.addSubview(cancelBtn)
        contentViews.insert(view, at: 0)
        
        refreshView()
    }
    
    @objc func deletePic(sender:UIButton){
        if  let view = sender.superview{
            let i = contentViews.index(of: view);
           
            contentViews.remove(at: i!)
           
            view.removeFromSuperview()
            
            refreshView()
        }
    }
    
    func refreshView(){
        //重新排列
        for i in 0..<contentViews.count{
            let view = contentViews[i]
            let width = view.frame.size.width
            view.frame = CGRect(x: 20 + (width + 10) * CGFloat(i % columnCount), y: 10 + (width + 10) * CGFloat(i / columnCount), width: width, height: width)
        }
        //改变本身的大小
        var frame = self.frame
        let maxY = (selectButton?.frame.maxY)!
      
        frame.size.height = maxY + CGFloat(10)
        self.frame = frame
        
        
        
    }

}

extension PicSelectView:UIImagePickerControllerDelegate,UINavigationControllerDelegate{
    
    func imagePickerController(_ picker: UIImagePickerController, didFinishPickingMediaWithInfo info: [UIImagePickerController.InfoKey : Any]) {
        let image : UIImage = info[UIImagePickerController.InfoKey.originalImage] as! UIImage
        addPicture(image: image)
         picker.dismiss(animated: true, completion: nil)
    }
    func imagePickerControllerDidCancel(_ picker: UIImagePickerController) {
        self.viewController()?.dismiss(animated: true, completion: { 
            
        })
    }
    
    
}
